<?php

if ( ! defined( 'ABSPATH' ) ) :
    exit; // Exit if accessed directly
endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Adds custom classes to the array of body classes.
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_body_classes' ) ) :

	function markety_body_classes( $classes ) {
		
		// header style classes
		if (function_exists('rwmb_meta')) :
			$page_header = rwmb_meta('markety_header_style');
			if ($page_header == 'header-default') :
				$classes[] = 'header-default';
			elseif($page_header == 'header-transparent') :
				$classes[] = 'header-transparent';
			else :
				$classes[] = markety_option('header-style', false, 'header-default');
			endif;
		endif;

		// footer style classes
		if (function_exists('rwmb_meta')) :
			$page_footer = rwmb_meta('markety_footer_style');
			if ($page_footer == 'footer-default') :
				$classes[] = 'footer-default';
			elseif($page_footer == 'footer-three-column') :
				$classes[] = 'footer-three-column';
			elseif($page_footer == 'footer-four-column') :
				$classes[] = 'footer-four-column';
			elseif($page_footer == 'footer-onepage') :
				$classes[] = 'footer-onepage';
			else :
				$classes[] = markety_option('footer-style', false, 'header-default');
			endif;
		endif;

		if (markety_option('top-border-style', false, true)) :
			$classes[ ] = 'has-top-border-style';
		endif;

		if (markety_option('analysis-button-visibility', false, true)) :
			$classes[ ] = 'has-analysis-btn';
		endif;

		if (markety_option('rtl')) {
			$classes[ ] = 'active-rtl';
		}

		$classes[] = markety_option('footer-style', false, 'footer-multipage');

		// Adds a class of group-blog to blogs with more than 1 published author.
		if ( is_multi_author() ) :
			$classes[ ] = 'group-blog';
		endif;

		if (markety_option('logo', 'url')) {
			$classes[] = 'has-site-logo';
		}
		if (markety_option('mobile-logo', 'url')) {
			$classes[] = 'has-mobile-logo';
		}
		if (markety_option('sticky-logo', 'url')) {
			$classes[] = 'has-sticky-logo';
		}
		if (markety_option('sticky-mobile-logo', 'url')) {
			$classes[] = 'has-sticky-mobile-logo';
		}

		return $classes;
	}
	add_filter( 'body_class', 'markety_body_classes' );

endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_page_menu_args' ) ) :

	function markety_page_menu_args( $args ) {

		$args[ 'show_home' ] = TRUE;

		return $args;
	}

	add_filter( 'wp_page_menu_args', 'markety_page_menu_args' );

endif;



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Sets the authordata global when viewing an author archive.
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_setup_author' ) ) :
	function markety_setup_author() {
		global $wp_query;

		if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
			$GLOBALS[ 'authordata' ] = get_userdata( $wp_query->post->post_author );
		}
	}

	add_action( 'wp', 'markety_setup_author' );

endif;



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Page break button in editor
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_wp_page_pagination' ) ) :

	function markety_wp_page_pagination( $mce_buttons ) {
		if ( get_post_type() == 'post' or get_post_type() == 'page' ) {
			$pos = array_search( 'wp_more', $mce_buttons, TRUE );
			if ( $pos !== FALSE ) {
				$buttons     = array_slice( $mce_buttons, 0, $pos + 1 );
				$buttons[ ]  = 'wp_page';
				$mce_buttons = array_merge( $buttons, array_slice( $mce_buttons, $pos + 1 ) );
			}
		}

		return $mce_buttons;
	}

	add_filter( 'mce_buttons', 'markety_wp_page_pagination' );

endif;



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Extend user contact
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
if (!function_exists('markety_extend_user_contact')) :
    function markety_extend_user_contact( $markety_user_contact) {
        
        $markety_user_contact['facebook_profile'] = esc_html__('Facebook Profile URL', 'markety');
        $markety_user_contact['twitter_profile'] = esc_html__('Twitter Profile URL', 'markety');
        $markety_user_contact['google_profile'] = esc_html__('Google Profile URL', 'markety');
        $markety_user_contact['linkedin_profile'] = esc_html__('Linkedin Profile URL', 'markety');
        $markety_user_contact['instagram_profile'] = esc_html__('Instagram Profile URL', 'markety');
        
        return $markety_user_contact;
    }

    add_filter( 'user_contactmethods', 'markety_extend_user_contact');

endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Set post view on single page
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_put_post_view_function' ) ) :

    function markety_put_post_view_function( $contents ) {
        if ( function_exists( 'markety_set_post_views' ) and is_single() ) {
            markety_set_post_views(get_the_ID());
        }

        return $contents;
    }

    add_filter( 'the_content', 'markety_put_post_view_function', 9999 );

endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Get site url by replacing 'http://site_url/' for one page menu
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_get_site_url' ) ) :

	function markety_get_site_url($output) {

		global $post;
		$front_id = get_option('page_on_front');
		
		if(is_object($post)) :
			$output = str_replace( 'http://site_url/', get_permalink($front_id), $output);	
			$output = str_replace( get_permalink($post->ID).'#', '#', $output );
		endif;

	    return $output;
	}
	add_filter( 'walker_nav_menu_start_el', 'markety_get_site_url', 10, 4);
endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Redux News Flash Remove 
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! class_exists( 'reduxNewsflash' ) ):
	class reduxNewsflash {
		public function __construct( $parent, $params ) {

		}
	}
endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Redux Ads Remove
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

	add_filter( 'redux/' . 'markety_theme_option' . '/aURL_filter', '__return_empty_string' );



//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Change number of products per row
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_product_per_row' ) ) :

	function markety_product_per_row() {
		$product_per_row = 3;

		if (markety_option('product-column')) :
			return markety_option('product-column', false, true); // products per row
		else :
			return $product_per_row;
		endif;
	}
	
	add_filter('loop_shop_columns', 'markety_product_per_row');

endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
// Product per page
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
if (!function_exists('markety_shop_per_page')) :
	function markety_shop_per_page(){
		$product_per_page = 6;

		if (markety_option('product-per-page')) :
			return markety_option('product-per-page', false, true); // products per page
		else :
			return $product_per_page;
		endif;
	}
	add_filter( 'loop_shop_per_page', 'markety_shop_per_page');
endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
//  Change shop thumbnail image size
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_shop_thumbnail_image_size' ) ):

    function markety_shop_thumbnail_image_size( $size ) {
        $size[ 'width' ]  = 60;
        $size[ 'height' ] = 60;
        $size[ 'crop' ]   = 1;

        return $size;
    }

    add_filter( 'woocommerce_get_image_size_shop_thumbnail', 'markety_shop_thumbnail_image_size' );

endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
//  Change shop catalog image size
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_shop_catalog_image_size' ) ):

    function markety_shop_catalog_image_size( $size ) {
        $size[ 'width' ]  = 175;
        $size[ 'height' ] = 260;
        $size[ 'crop' ]   = 1;

        return $size;
    }

    add_filter( 'woocommerce_get_image_size_shop_catalog', 'markety_shop_catalog_image_size' );
endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
//  Change shop single image size
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_shop_single_image_size' ) ):

    function markety_shop_single_image_size( $size ) {
        $size[ 'width' ]  = 340;
        $size[ 'height' ] = 530;
        $size[ 'crop' ]   = 1;

        return $size;
    }

    add_filter( 'woocommerce_get_image_size_shop_single', 'markety_shop_single_image_size' );
endif;


//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
//  Before cart markup
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_before_cart_div' ) ):

    function markety_before_cart_div( ) {
        echo '<div class="markety-shop markety-cart">';
    }

    add_action( 'woocommerce_before_cart', 'markety_before_cart_div' );
endif;

//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
//  after cart markup
//-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

if ( ! function_exists( 'markety_after_cart_div' ) ):

    function markety_after_cart_div( ) {
        echo '</div>';
    }

    add_action( 'woocommerce_after_cart', 'markety_after_cart_div' );
endif;